==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/action.admin_templates.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Templates') ) return;

echo '<div class="pageoverflow" style="text-align: right; width: 80%;">'.
$this->CreateImageLink($id,'defaultadmin',$returnid,
		       $this->Lang('lbl_back'),'icons/system/back.gif',array(),'','',false).'</div><br/>';

echo $this->StartTabHeaders();
echo $this->SetTabHeader('list_checkins',$this->Lang('tab_list_checkins_templates'));
echo $this->SetTabHeader('list_activities',$this->Lang('tab_list_activities_templates'));
echo $this->SetTabHeader('view_activity',$this->Lang('tab_view_activity_templates'));
echo $this->SetTabHeader('default_templates',$this->Lang('tab_default_templates'));
echo $this->EndTabHeaders();

echo $this->StartTabContent();
echo $this->StartTab('list_checkins',$params);
include(dirname(__FILE__).'/function.admin_list_checkins_tab.php');
echo $this->EndTab();

echo $this->StartTab('list_activities',$params);
include(dirname(__FILE__).'/function.admin_list_activities_tab.php');
echo $this->EndTab();

echo $this->StartTab('view_activity',$params);
include(dirname(__FILE__).'/function.admin_view_activity_tab.php');
echo $this->EndTab();
  
echo $this->StartTab('default_templates',$params);
include(dirname(__FILE__).'/function.admin_default_templates_tab.php');
echo $this->EndTab();
echo $this->EndTabContent();

#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/action.admin_templates.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Templates') ) return;

echo '<div class="pageoverflow" style="text-align: right; width: 80%;">'.
$this->CreateImageLink($id,'defaultadmin',$returnid,
		       $this->Lang('lbl_back'),'icons/system/back.gif',array(),'','',false).'</div><br/>';

echo $this->StartTabHeaders();
echo $this->SetTabHeader('add_checkin',$this->Lang('tab_add_checkin_templates'));
echo $this->SetTabHeader('list_checkins',$this->Lang('tab_list_checkins_templates'));
echo $this->SetTabHeader('view_checkin',$this->Lang('tab_view_checkin_templates'));
echo $this->SetTabHeader('list_activities',$this->Lang('tab_list_activities_templates'));
echo $this->SetTabHeader('view_activity',$this->Lang('tab_view_activity_templates'));
echo $this->SetTabHeader('friendreq',$this->Lang('tab_friendreq_templates'));
echo $this->SetTabHeader('friendreqlist',$this->Lang('tab_friendreqlist_templates'));
echo $this->SetTabHeader('badgesummary',$this->Lang('tab_badgesummary_templates'));
echo $this->SetTabHeader('badgedetail',$this->Lang('tab_badgedetail_templates'));
echo $this->SetTabHeader('leaderboardsummary',$this->Lang('tab_leaderboardsummary_templates'));
echo $this->SetTabHeader('leaderboarddetail',$this->Lang('tab_leaderboarddetail_templates'));
echo $this->SetTabHeader('default_templates',$this->Lang('tab_default_templates'));
echo $this->EndTabHeaders();

echo $this->StartTabContent();
echo $this->StartTab('add_checkin',$params);
include(__DIR__.'/function.admin_add_checkin_tab.php');
echo $this->EndTab();

echo $this->StartTab('list_checkins',$params);
include(__DIR__.'/function.admin_list_checkins_tab.php');
echo $this->EndTab();

echo $this->StartTab('view_checkin',$params);
include(__DIR__.'/function.admin_view_checkin_tab.php');
echo $this->EndTab();

echo $this->StartTab('list_activities',$params);
include(__DIR__.'/function.admin_list_activities_tab.php');
echo $this->EndTab();

echo $this->StartTab('view_activity',$params);
include(__DIR__.'/function.admin_view_activity_tab.php');
echo $this->EndTab();

echo $this->StartTab('friendreq',$params);
include(__DIR__.'/function.admin_friendreq_tab.php');
echo $this->EndTab();

echo $this->StartTab('friendreqlist',$params);
include(__DIR__.'/function.admin_friendreqlist_tab.php');
echo $this->EndTab();

echo $this->StartTab('badgesummary',$params);
include(__DIR__.'/function.admin_badgesummary_tab.php');
echo $this->EndTab();

echo $this->StartTab('badgedetail',$params);
include(__DIR__.'/function.admin_badgedetail_tab.php');
echo $this->EndTab();

echo $this->StartTab('leaderboardsummary',$params);
include(__DIR__.'/function.admin_leaderboardsummary_tab.php');
echo $this->EndTab();

echo $this->StartTab('leaderboarddetail',$params);
include(__DIR__.'/function.admin_leaderboarddetail_tab.php');
echo $this->EndTab();

echo $this->StartTab('default_templates',$params);
include(__DIR__.'/function.admin_default_templates_tab.php');
echo $this->EndTab();
echo $this->EndTabContent();

#
# EOF
#
?>
